@@ -16,6 +16,7 @@ pub use channel::*;
 pub use contact::*;
 pub use credential::*;
 pub use entity::*;
+pub use entity_builder::*;
 pub use error::*;
 pub use identifiers::*;
 pub use key_attributes::*;
@@ -98,6 +99,7 @@ mod channel;
 mod contact;
 mod credential;
 mod entity;
+mod entity_builder;
 mod error;
 mod identifiers;
 mod key_attributes;
