@@ -6,10 +6,11 @@ use crate::change_history::ProfileChangeHistory;
 use crate::{
     authentication::Authentication,
     profile::Profile,
-    AuthenticationProof, BlsPublicKey, BlsSecretKey, Changes, Contact, Contacts, Credential,
-    CredentialAttribute, CredentialAttributeType, CredentialError, CredentialFragment1,
+    AuthenticationProof, BbsCredential, BlsPublicKey, BlsSecretKey, Changes, Contact, Contacts,
+    Credential, CredentialAttribute, CredentialAttributeType, CredentialError, CredentialFragment1,
     CredentialFragment2, CredentialHolder, CredentialIssuer, CredentialOffer,
-    CredentialPresentation, CredentialRequest, CredentialSchema, CredentialVerifier, EntityError,
+    CredentialPresentation, CredentialRequest, CredentialSchema, CredentialVerifier,
+    EntityCredential, EntityError,
     EntityError::{ContactVerificationFailed, InvalidInternalState},
     EventIdentifier, ExtPokSignatureProof, Identity, KeyAttributes, MetaKeyAttributes, OfferId,
     PresentationManifest, ProfileChangeEvent, ProfileEventAttributes, ProfileIdentifier,
@@ -33,6 +34,7 @@ pub struct ProfileState {
     contacts: Contacts,
     vault: VaultSync,
     rand_msg: Message,
+    credentials: Vec<EntityCredential>,
 }
 
 impl ProfileState {
@@ -50,6 +52,7 @@ impl ProfileState {
             contacts,
             vault,
             rand_msg: Message::random(rng),
+            credentials: vec![],
         }
     }
 
@@ -121,6 +124,31 @@ impl ProfileState {
         let key_id = self.vault.compute_key_id_for_public_key(&public_key)?;
         self.vault.get_secret_by_key_id(&key_id)
     }
+
+    pub fn add_credential(&mut self, credential: EntityCredential) -> Result<()> {
+        if let Some(_) = self
+            .credentials
+            .iter()
+            .find(|x| x.credential() == credential.credential())
+        {
+            return Err(EntityError::DuplicateCredential.into());
+        }
+        self.credentials.push(credential);
+
+        Ok(())
+    }
+
+    pub fn get_credential(&mut self, credential: &Credential) -> Result<EntityCredential> {
+        if let Some(c) = self
+            .credentials
+            .iter()
+            .find(|x| x.credential() == credential)
+        {
+            return Ok(c.clone());
+        }
+
+        Err(EntityError::CredentialNotFound.into())
+    }
 }
 
 impl Identity for ProfileState {
@@ -316,7 +344,7 @@ impl CredentialIssuer for ProfileState {
         &mut self,
         schema: &CredentialSchema,
         attributes: &[CredentialAttribute],
-    ) -> Result<Credential> {
+    ) -> Result<BbsCredential> {
         if schema.attributes.len() != attributes.len() {
             return Err(CredentialError::MismatchedAttributesAndClaims.into());
         }
@@ -343,7 +371,7 @@ impl CredentialIssuer for ProfileState {
 
         let signature = BbsIssuer::sign(&self.get_signing_key()?, &generators, &messages)
             .map_err(|_| CredentialError::MismatchedAttributesAndClaims)?;
-        Ok(Credential {
+        Ok(BbsCredential {
             attributes: attributes.to_vec(),
             signature,
         })
@@ -458,7 +486,7 @@ impl CredentialHolder for ProfileState {
         &mut self,
         credential_fragment1: CredentialFragment1,
         credential_fragment2: CredentialFragment2,
-    ) -> Result<Credential> {
+    ) -> Result<BbsCredential> {
         let mut attributes = credential_fragment2.attributes;
         for i in 0..credential_fragment1.schema.attributes.len() {
             if credential_fragment1.schema.attributes[i].label == SECRET_ID {
@@ -466,7 +494,7 @@ impl CredentialHolder for ProfileState {
                 break;
             }
         }
-        Ok(Credential {
+        Ok(BbsCredential {
             attributes,
             signature: credential_fragment2
                 .signature
@@ -476,7 +504,7 @@ impl CredentialHolder for ProfileState {
 
     fn is_valid_credential(
         &mut self,
-        credential: &Credential,
+        credential: &BbsCredential,
         verifier_key: SigningPublicKey,
     ) -> Result<bool> {
         // credential cannot have zero attributes so unwrap is okay
@@ -493,7 +521,7 @@ impl CredentialHolder for ProfileState {
 
     fn present_credentials(
         &mut self,
-        credential: &[Credential],
+        credential: &[BbsCredential],
         presentation_manifests: &[PresentationManifest],
         proof_request_id: ProofRequestId,
     ) -> Result<Vec<CredentialPresentation>> {
